==> qt-creator-opensource-src-4.6.0.zip: qt-creator-opensource-src-4.6.0/src/shared/qbs/src/lib/corelib/buildgraph/abstractcommandexecutor.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "abstractcommandexecutor.h"

#include "rulecommands.h"

#include <logging/translator.h>
#include <tools/error.h>

namespace qbs {
namespace Internal {

AbstractCommandExecutor::AbstractCommandExecutor(const Logger &logger, QObject *parent)
    : QObject(parent)
    , m_echoMode(defaultCommandEchoMode())
    , m_command(nullptr)
    , m_transformer(nullptr)
    , m_mainThreadScriptEngine(nullptr)
    , m_dryRun(false)
    , m_logger(logger)
{
}

void AbstractCommandExecutor::start(Transformer *transformer, const AbstractCommand *cmd)
{
    m_transformer = transformer;
    m_command = cmd;
    doSetup();
    doReportCommandDescription();
    doStart();
}

void AbstractCommandExecutor::doReportCommandDescription()
{
    if (m_command->isSilent() || m_echoMode == CommandEchoModeSilent)
        return;

    if (m_command->description().isEmpty()) {
        m_logger.printWarning(
                    ErrorInfo(Tr::tr("Command is not marked silent, but has no description."),
                              m_command->codeLocation()));
    } else {
        emit reportCommandDescription(m_command->highlight(), m_command->description());
    }
}

} // namespace Internal
} // namespace qbs

==> qt-creator-opensource-src-4.10.2.zip: qt-creator-opensource-src-4.10.2/src/shared/qbs/src/lib/corelib/buildgraph/abstractcommandexecutor.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "abstractcommandexecutor.h"

#include "rulecommands.h"
#include "transformer.h"

#include <language/language.h>
#include <logging/translator.h>
#include <tools/error.h>

namespace qbs {
namespace Internal {

AbstractCommandExecutor::AbstractCommandExecutor(Logger logger, QObject *parent)
    : QObject(parent)
    , m_echoMode(defaultCommandEchoMode())
    , m_command(nullptr)
    , m_transformer(nullptr)
    , m_mainThreadScriptEngine(nullptr)
    , m_dryRun(false)
    , m_logger(std::move(logger))
{
}

void AbstractCommandExecutor::start(Transformer *transformer, AbstractCommand *cmd)
{
    m_transformer = transformer;
    m_command = cmd;
    doSetup();
    doReportCommandDescription(transformer->product()->fullDisplayName());
    doStart();
}

void AbstractCommandExecutor::doReportCommandDescription(const QString &productName)
{
    if (m_command->isSilent() || m_echoMode == CommandEchoModeSilent)
        return;

    if (m_command->description().isEmpty()) {
        m_logger.printWarning(
                    ErrorInfo(Tr::tr("Command is not marked silent, but has no description."),
                              m_command->codeLocation()));
    } else {
        emit reportCommandDescription(m_command->highlight(),
                                      m_command->fullDescription(productName));
    }
}

} // namespace Internal
} // namespace qbs
